==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/iotoperationsorchestrator/kotlin/inputs/ReconciliationPolicyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.iotoperationsorchestrator.kotlin.inputs

import com.pulumi.azurenative.iotoperationsorchestrator.inputs.ReconciliationPolicyArgs.builder
import com.pulumi.azurenative.iotoperationsorchestrator.kotlin.enums.ReconciliationPolicies
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Reconciliation Policy.
 * @property interval Policy interval.
 * @property type Policy type
 */
public data class ReconciliationPolicyArgs(
    public val interval: Output<String>? = null,
    public val type: Output<Either<String, ReconciliationPolicies>>,
) :
    ConvertibleToJava<com.pulumi.azurenative.iotoperationsorchestrator.inputs.ReconciliationPolicyArgs> {
    override fun toJava():
        com.pulumi.azurenative.iotoperationsorchestrator.inputs.ReconciliationPolicyArgs =
        com.pulumi.azurenative.iotoperationsorchestrator.inputs.ReconciliationPolicyArgs.builder()
            .interval(interval?.applyValue({ args0 -> args0 }))
            .type(
                type.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ReconciliationPolicyArgs].
 */
@PulumiTagMarker
public class ReconciliationPolicyArgsBuilder internal constructor() {
    private var interval: Output<String>? = null

    private var type: Output<Either<String, ReconciliationPolicies>>? = null

    /**
     * @param value Policy interval.
     */
    @JvmName("xwprswxoeabcofsn")
    public suspend fun interval(`value`: Output<String>) {
        this.interval = value
    }

    /**
     * @param value Policy type
     */
    @JvmName("hsiiccmuoydvikqa")
    public suspend fun type(`value`: Output<Either<String, ReconciliationPolicies>>) {
        this.type = value
    }

    /**
     * @param value Policy interval.
     */
    @JvmName("nxbmbdimleqjuhfe")
    public suspend fun interval(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.interval = mapped
    }

    /**
     * @param value Policy type
     */
    @JvmName("cmyvckxjkpkbxwds")
    public suspend fun type(`value`: Either<String, ReconciliationPolicies>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Policy type
     */
    @JvmName("ggdwlciwhhmjdgdx")
    public fun type(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ReconciliationPolicies>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Policy type
     */
    @JvmName("xfnmagdkddrufvut")
    public fun type(`value`: ReconciliationPolicies) {
        val toBeMapped = Either.ofRight<String, ReconciliationPolicies>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): ReconciliationPolicyArgs = ReconciliationPolicyArgs(
        interval = interval,
        type = type ?: throw PulumiNullFieldException("type"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/iotoperationsorchestrator/kotlin/inputs/ReconciliationPolicyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.iotoperationsorchestrator.kotlin.inputs

import com.pulumi.azurenative.iotoperationsorchestrator.inputs.ReconciliationPolicyArgs.builder
import com.pulumi.azurenative.iotoperationsorchestrator.kotlin.enums.ReconciliationPolicies
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Reconciliation Policy.
 * @property interval Policy interval.
 * @property type Policy type
 */
public data class ReconciliationPolicyArgs(
    public val interval: Output<String>? = null,
    public val type: Output<Either<String, ReconciliationPolicies>>,
) :
    ConvertibleToJava<com.pulumi.azurenative.iotoperationsorchestrator.inputs.ReconciliationPolicyArgs> {
    override fun toJava():
        com.pulumi.azurenative.iotoperationsorchestrator.inputs.ReconciliationPolicyArgs =
        com.pulumi.azurenative.iotoperationsorchestrator.inputs.ReconciliationPolicyArgs.builder()
            .interval(interval?.applyValue({ args0 -> args0 }))
            .type(
                type.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ReconciliationPolicyArgs].
 */
@PulumiTagMarker
public class ReconciliationPolicyArgsBuilder internal constructor() {
    private var interval: Output<String>? = null

    private var type: Output<Either<String, ReconciliationPolicies>>? = null

    /**
     * @param value Policy interval.
     */
    @JvmName("fxelhcpwbredouiu")
    public suspend fun interval(`value`: Output<String>) {
        this.interval = value
    }

    /**
     * @param value Policy type
     */
    @JvmName("uswrdaasneytebcd")
    public suspend fun type(`value`: Output<Either<String, ReconciliationPolicies>>) {
        this.type = value
    }

    /**
     * @param value Policy interval.
     */
    @JvmName("rerpbabtfwafkdgp")
    public suspend fun interval(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.interval = mapped
    }

    /**
     * @param value Policy type
     */
    @JvmName("dpthvntyrpcoeqmo")
    public suspend fun type(`value`: Either<String, ReconciliationPolicies>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Policy type
     */
    @JvmName("xmpjcvrhhekblrfc")
    public fun type(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ReconciliationPolicies>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Policy type
     */
    @JvmName("qyskfxikahbwrmqg")
    public fun type(`value`: ReconciliationPolicies) {
        val toBeMapped = Either.ofRight<String, ReconciliationPolicies>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): ReconciliationPolicyArgs = ReconciliationPolicyArgs(
        interval = interval,
        type = type ?: throw PulumiNullFieldException("type"),
    )
}
